package com.zjsgfa.project.zjsgfa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zjsgfa.project.zjsgfa.mapper.SjBcxxMapper;
import com.zjsgfa.project.zjsgfa.domain.SjBcxx;
import com.zjsgfa.project.zjsgfa.service.ISjBcxxService;

/**
 * 方案补充信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2026-03-05
 */
@Service
public class SjBcxxServiceImpl implements ISjBcxxService 
{
    @Autowired
    private SjBcxxMapper sjBcxxMapper;

    /**
     * 查询方案补充信息
     * 
     * @param id 方案补充信息主键
     * @return 方案补充信息
     */
    @Override
    public SjBcxx selectSjBcxxById(Long id)
    {
        return sjBcxxMapper.selectSjBcxxById(id);
    }

    /**
     * 查询方案补充信息列表
     * 
     * @param sjBcxx 方案补充信息
     * @return 方案补充信息
     */
    @Override
    public List<SjBcxx> selectSjBcxxList(SjBcxx sjBcxx)
    {
        return sjBcxxMapper.selectSjBcxxList(sjBcxx);
    }

    /**
     * 新增方案补充信息
     * 
     * @param sjBcxx 方案补充信息
     * @return 结果
     */
    @Override
    public int insertSjBcxx(SjBcxx sjBcxx)
    {
        return sjBcxxMapper.insertSjBcxx(sjBcxx);
    }

    /**
     * 修改方案补充信息
     * 
     * @param sjBcxx 方案补充信息
     * @return 结果
     */
    @Override
    public int updateSjBcxx(SjBcxx sjBcxx)
    {
        return sjBcxxMapper.updateSjBcxx(sjBcxx);
    }

    /**
     * 批量删除方案补充信息
     * 
     * @param ids 需要删除的方案补充信息主键
     * @return 结果
     */
    @Override
    public int deleteSjBcxxByIds(Long[] ids)
    {
        return sjBcxxMapper.deleteSjBcxxByIds(ids);
    }

    /**
     * 删除方案补充信息信息
     * 
     * @param id 方案补充信息主键
     * @return 结果
     */
    @Override
    public int deleteSjBcxxById(Long id)
    {
        return sjBcxxMapper.deleteSjBcxxById(id);
    }
}
